RoundedDashedBorder

Struct RoundedDashedBorder 

pub struct RoundedDashedBorder(pub Borders);
A dashed border with rounded corners.

This is a wrapper around Borders with Deref and DerefMut implementations for convenient access to the underlying Borders configuration.

Examples

use ratatui_garnish::border::{Borders, RoundedDashedBorder};

let border = RoundedDashedBorder::default();
let custom = RoundedDashedBorder::new(Borders::TOP | Borders::BOTTOM);

Tuple Fields

0: Borders

Implementations

Source

impl RoundedDashedBorder

pub const fn new(borders: Borders) -> Self

Creates a new border with the specified configuration.

Methods from Deref<Target = Borders>

pub const NONE: Self

pub const TOP: Self

pub const RIGHT: Self

pub const BOTTOM: Self

pub const LEFT: Self

pub const ALL: Self

pub fn bits(&self) -> u8

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub fn iter(&self) -> Iter<Borders>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub fn iter_names(&self) -> IterNames<Borders>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.