pub struct Padding {
pub left: u16,
pub right: u16,
pub top: u16,
pub bottom: u16,
}Expand description
Padding garnish.
This Padding is a fork of Ratatui::widgets::block::padding but
supports serde with the serde feature enabled
This concept is similar to CSS padding and CSS Margin depending on which garnishes follow it.
NOTE: Terminal cells are often taller than they are wide, so to make horizontal and vertical padding seem equal, doubling the horizontal padding is usually pretty good.
Example
use ratatui_garnish::Padding;
Padding::uniform(1);
Padding::horizontal(2);
Padding::left(3);
Padding::proportional(4);
Padding::symmetric(5, 6);Fields
left: u16Left padding
right: u16Right padding
top: u16Top padding
bottom: u16Bottom padding
Implementations
Sourceimpl Padding
impl Padding
Sourcepub const fn new(left: u16, right: u16, top: u16, bottom: u16) -> Self
pub const fn new(left: u16, right: u16, top: u16, bottom: u16) -> Self
Creates a new Padding by specifying every field individually.
Note: the order of the fields does not match the order of the CSS properties.
Sourcepub const fn horizontal(value: u16) -> Self
pub const fn horizontal(value: u16) -> Self
Creates a Padding with the same value for left and right.
Sourcepub const fn vertical(value: u16) -> Self
pub const fn vertical(value: u16) -> Self
Creates a Padding with the same value for top and bottom.
Sourcepub const fn proportional(value: u16) -> Self
pub const fn proportional(value: u16) -> Self
Creates a Padding that is visually proportional to the terminal.
This represents a padding of 2x the value for left and right and 1x the value for
top and bottom.